@@ -385,7 +385,7 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Enable Losseless Compression</source>
+        <source>Enable Lossless Compression</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -958,6 +958,10 @@ Klepněte na Zrušit pro zrušení všech operací.</translation>
         <source>Analyzing the file. It may take a while, please wait...</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Converted</source>
+        <translation type="unfinished">Převedeno</translation>
+    </message>
 </context>
 <context>
     <name>PixTreeWidget</name>
